@@ -134,7 +134,8 @@ class so_map:
             cdelt = self.data.wcs.wcs.cdelt[1]
             l_max_limit = 360 / cdelt / 4
         return l_max_limit
-
+        
+                
     def plot(
         self,
         color="planck",
@@ -212,7 +213,7 @@ class so_map:
                 if file_name is not None:
                     plt.savefig(file_name + ".png", bbox_inches="tight")
                     plt.clf()
-                    plt.close
+                    plt.close()
                 else:
                     plt.show()
             else:
@@ -252,7 +253,7 @@ class so_map:
                     if file_name is not None:
                         plt.savefig(file_name + "_%s" % field + ".png", bbox_inches="tight")
                         plt.clf()
-                        plt.close
+                        plt.close()
                     else:
                         plt.show()
 
@@ -427,7 +428,7 @@ def from_components(T, Q, U):
     return new_map
 
 
-def get_submap_car(map_car, box, mode):
+def get_submap_car(map_car, box, mode="round"):
     """Cut a CAR submap (using pixell).
 
     Parameters
@@ -636,6 +637,33 @@ def car_template(ncomp, ra0, ra1, dec0, dec1, res):
     temp.coordinate = "equ"
     return temp
 
+def full_sky_car_template(ncomp, res):
+    """Create a ``so_map`` full sky template with CAR pixellisation in equ coordinates.
+
+    Parameters
+    ----------
+    ncomp: integer
+        the number of components of the map can be 1 or 3 (for T,Q,U)
+    res: float
+        resolution in arcminute
+    """
+
+    if ncomp == 3:
+        pre = (3,)
+    else:
+        pre = ()
+
+    res = res * np.pi / (180 * 60)
+    temp = so_map()
+    shape, wcs = enmap.fullsky_geometry(res=res, dims=pre)
+    temp.data = enmap.zeros(shape, wcs=wcs, dtype=None)
+    temp.pixel = "CAR"
+    temp.nside = None
+    temp.ncomp = ncomp
+    temp.geometry = temp.data.geometry[1:]
+    temp.coordinate = "equ"
+    return temp
+
 
 def white_noise(template, rms_uKarcmin_T, rms_uKarcmin_pol=None):
     """Generate a white noise realisation corresponding to the template pixellisation
